Rev 2532: Turn list-weave into list-versionedfile in file:///home/pqm/archives/thelove/bzr/%2Btrunk/

Canonical.com Patch Queue Manager pqm at pqm.ubuntu.com
Mon Jun 18 06:22:37 BST 2007


At file:///home/pqm/archives/thelove/bzr/%2Btrunk/

------------------------------------------------------------
revno: 2532
revision-id: pqm at pqm.ubuntu.com-20070618052235-mvns8j28szyzscy0
parent: pqm at pqm.ubuntu.com-20070618033356-q24jtmuwbf03ojvd
parent: aaron.bentley at utoronto.ca-20070618045658-a2sjuk0r29yx610c
committer: Canonical.com Patch Queue Manager<pqm at pqm.ubuntu.com>
branch nick: +trunk
timestamp: Mon 2007-06-18 06:22:35 +0100
message:
  Turn list-weave into list-versionedfile
modified:
  NEWS                           NEWS-20050323055033-4e00b5db738777ff
  bzrlib/builtins.py             builtins.py-20050830033751-fc01482b9ca23183
  bzrlib/weave_commands.py       weave_commands.py-20060320231507-8e9f300bffc1aa19
    ------------------------------------------------------------
    revno: 1551.2.49.1.40.1.22.1.42.1.31.1.39.1.17.1.27
    merged: aaron.bentley at utoronto.ca-20070618045658-a2sjuk0r29yx610c
    parent: aaron.bentley at utoronto.ca-20070618045410-nysseluvoupymb9i
    committer: Aaron Bentley <aaron.bentley at utoronto.ca>
    branch nick: Aaron's mergeable stuff
    timestamp: Mon 2007-06-18 00:56:58 -0400
    message:
      fix NEWS
    ------------------------------------------------------------
    revno: 1551.2.49.1.40.1.22.1.42.1.31.1.39.1.17.1.26
    merged: aaron.bentley at utoronto.ca-20070618045410-nysseluvoupymb9i
    parent: aaron.bentley at utoronto.ca-20070618024552-ya7hg0rd1e9fo1ym
    committer: Aaron Bentley <aaron.bentley at utoronto.ca>
    branch nick: Aaron's mergeable stuff
    timestamp: Mon 2007-06-18 00:54:10 -0400
    message:
      Update NEWS
    ------------------------------------------------------------
    revno: 1551.2.49.1.40.1.22.1.42.1.31.1.39.1.17.1.25
    merged: aaron.bentley at utoronto.ca-20070618024552-ya7hg0rd1e9fo1ym
    parent: aaron.bentley at utoronto.ca-20070617223937-nziy1cki818xykth
    parent: pqm at pqm.ubuntu.com-20070615082222-98j9j9nbl6p2dx0m
    committer: Aaron Bentley <aaron.bentley at utoronto.ca>
    branch nick: Aaron's mergeable stuff
    timestamp: Sun 2007-06-17 22:45:52 -0400
    message:
      Merge from bzr.dev
    ------------------------------------------------------------
    revno: 1551.2.49.1.40.1.22.1.42.1.31.1.39.1.17.1.24
    merged: aaron.bentley at utoronto.ca-20070617223937-nziy1cki818xykth
    parent: aaron.bentley at utoronto.ca-20070613030239-yrkk8z0m5me87fpp
    committer: Aaron Bentley <aaron.bentley at utoronto.ca>
    branch nick: Aaron's mergeable stuff
    timestamp: Sun 2007-06-17 18:39:37 -0400
    message:
      Make list-weave list knits, rename to list-versionedfile
=== modified file 'NEWS'
--- a/NEWS	2007-06-15 07:28:49 +0000
+++ b/NEWS	2007-06-18 04:56:58 +0000
@@ -16,6 +16,9 @@
     * ``bzr missing`` now has better option names ``--this`` and ``--other``.
       (Elliot Murphy)
 
+    * The internal ``weave-list`` command has become ``versionedfile-list``,
+      and now lists knits as well as weaves.  (Aaron Bentley)
+
   TESTING:
 
     * Removed the ``--keep-output`` option from selftest and clean up test

=== modified file 'bzrlib/builtins.py'
--- a/bzrlib/builtins.py	2007-06-15 07:28:49 +0000
+++ b/bzrlib/builtins.py	2007-06-18 02:45:52 +0000
@@ -3807,5 +3807,5 @@
 from bzrlib.conflicts import cmd_resolve, cmd_conflicts, restore
 from bzrlib.bundle.commands import cmd_bundle_revisions
 from bzrlib.sign_my_commits import cmd_sign_my_commits
-from bzrlib.weave_commands import cmd_weave_list, cmd_weave_join, \
+from bzrlib.weave_commands import cmd_versionedfile_list, cmd_weave_join, \
         cmd_weave_plan_merge, cmd_weave_merge_text

=== modified file 'bzrlib/weave_commands.py'
--- a/bzrlib/weave_commands.py	2006-10-11 23:08:27 +0000
+++ b/bzrlib/weave_commands.py	2007-06-17 22:39:37 +0000
@@ -25,16 +25,25 @@
 from bzrlib.commands import Command
 from bzrlib.trace import warning
 
-class cmd_weave_list(Command):
-    """List the revision ids present in a weave, in alphabetical order"""
+class cmd_versionedfile_list(Command):
+    """List the revision ids present in a versionedfile, alphabetically"""
 
     hidden = True
-    takes_args = ['weave_filename']
+    takes_args = ['filename']
+    aliases = ['weave-list']
 
-    def run(self, weave_filename):
+    def run(self, filename):
         from bzrlib.weavefile import read_weave
-        weave = read_weave(file(weave_filename, 'rb'))
-        names = weave.versions()
+        from bzrlib.transport import get_transport
+        from bzrlib import osutils
+        from bzrlib.knit import KnitVersionedFile
+        if filename.endswith('.knit'):
+            transport = get_transport(osutils.dirname(filename))
+            relpath = osutils.basename(filename)[:-len('.knit')]
+            vf = KnitVersionedFile(relpath, transport)
+        else:
+            vf = read_weave(file(filename, 'rb'))
+        names = vf.versions()
         names.sort()
         print '\n'.join(names)
 




More information about the bazaar-commits mailing list